<vertex>

varying vec2 texCoord;
varying vec3 lightVec;
varying vec3 viewVec;

uniform vec3 lightPos;
uniform vec3 camPos;
uniform vec4 color;
uniform float invRadius;
//uniform float ambient;
uniform mat4 params;


void main() {
	gl_Position = gl_ModelViewProjectionMatrix * gl_Vertex;

	texCoord = gl_MultiTexCoord0.xy;
	
	//vec3 normal = normalize(gl_NormalMatrix * gl_Normal);
	//vec3 binormal = cross(gl_MultiTexCoord3.xyz, gl_MultiTexCoord1.xyz);

	vec3 lVec = lightPos - gl_Vertex.xyz;
	lightVec.x = dot(gl_MultiTexCoord1.xyz, lVec); // TAN
	lightVec.y = dot(gl_MultiTexCoord2.xyz, lVec); // Binormal - gl_MultiTexCoord2.xyz
	lightVec.z = dot(gl_Normal.xyz, lVec); // Normal 

	vec3 vVec = camPos - gl_Vertex.xyz;
	viewVec.x = dot(gl_MultiTexCoord1.xyz, vVec);
	viewVec.y = dot(gl_MultiTexCoord2.xyz, vVec);
	viewVec.z = dot(gl_Normal.xyz, vVec);

	gl_FrontColor = color;
}

/*
 *
 */
<fragment>

uniform sampler2D s_texture_0; // Base
uniform sampler2D s_texture_1; // Bump
//uniform sampler2D s_texture_2; // Height map
uniform sampler2D s_texture_3; // Sphere map or Detail map

varying vec2 texCoord;
varying vec3 lightVec;
varying vec3 viewVec;
//varying float ambient;
//varying float specularp;
uniform float invRadius;
//uniform float ambient;
uniform mat4 params;


void main(){
	float ambient = params[0].x;
	float specularp = params[0].y;

	// Parallax mapping
	//vec3 vVec = normalize(viewVec);
	//-float height = texture2D(s_texture_2, texCoord).x ;
	//vec2 newTexCoord = texCoord + ((height * 0.03 - 0.015) * (-vVec.xy));
	//-vec2 newTexCoord = texCoord + ((height * 0.04 - 0.02) * (-vVec.xy));
	
	//vec4 base = texture2D(s_texture_0, newTexCoord);
	//vec3 bump = normalize(texture2D(s_texture_1, newTexCoord).xyz * 2.0 - 1.0);

	vec4 base = texture2D(s_texture_0, texCoord);
	vec3 bump = texture2D(s_texture_1, texCoord).xyz * 2.0 - 1.0;

	bump = normalize(bump);

	float distSqr = dot(lightVec, lightVec);
	vec3 lVec = lightVec * inversesqrt(distSqr);

	float atten = clamp(1.0 - invRadius / 10000.0 * sqrt(distSqr), 0.0, 1.0);
	float diffuse = clamp(dot(lVec, bump), 0.0, 1.0);

	//float specular = 0.0;//pow(clamp(dot(reflect(normalize(-viewVec), bump), lVec), 0.0, 1.0), 16.0);
	gl_FragColor = (ambient * base + ((diffuse+0.2) * base ) * atten) * gl_Color ;
}